@@ -7,29 +7,10 @@
 #
 ##############################################################################
 
-from pprint import pformat
 from twisted.internet import defer
 from .client import WinrmClientFactory
 
 
-class Result(object):
-
-    def __repr__(self):
-        return '\n' + pformat(vars(self), indent=4)
-
-
-class ResultsAccumulator(object):
-
-    def __init__(self):
-        self.results = []
-
-    def new_instance(self):
-        self.results.append(Result())
-
-    def add_property(self, name, value):
-        setattr(self.results[-1], name, value)
-
-
 class WinrmCollectClient(object):
 
     def __init__(self):
@@ -38,13 +19,11 @@ class WinrmCollectClient(object):
     @defer.inlineCallbacks
     def do_collect(self, hostname, username, password, wqls):
         client = self._client_factory.create_winrm_client()
-        results = {}
+        items = {}
         for wql in wqls:
-            accumulator = ResultsAccumulator()
-            yield client.enumerate(hostname, username, password, wql,
-                                   accumulator)
-            results[wql] = accumulator.results
-        defer.returnValue(results)
+            items[wql] = yield client.enumerate(
+                hostname, username, password, wql)
+        defer.returnValue(items)
 
 
 # ----- An example of useage...
@@ -58,11 +37,11 @@ if __name__ == '__main__':
 
     @defer.inlineCallbacks
     def do_example_collect():
-        results = yield winrm.do_collect(
+        items = yield winrm.do_collect(
             "gilroy", "Administrator", "Z3n0ss",
             ['Select Caption, DeviceID, Name From Win32_Processor',
              'select Name, Label, Capacity from Win32_Volume'])
-        pprint(results)
+        pprint(items)
         reactor.stop()
 
     reactor.callWhenRunning(do_example_collect)
